@@ -3,6 +3,7 @@
 import gtk, gobject
 import gnome.gconf
 import hildon, osso
+import traceback
 import time
 import thread
 from hermes import Hermes
@@ -43,7 +44,7 @@ class HermesGUI:
         gobject.idle_add(hildon.hildon_banner_show_information, self.window, '', "Updated %d contacts" % (len(fb2c.updated)))
         gobject.idle_add(self.window.set_property, 'sensitive', True)
       except Exception, e:
-        print e
+        traceback.print_exc()
         gobject.idle_add(self.report_error, 'Something went wrong: ' + e.message)
 
 
@@ -166,7 +167,7 @@ class HermesGUI:
     self.app = hildon.Program()
     self.window = hildon.Window()
     gtk.set_application_name('Hermes')
-    osso_context = osso.Context('org.maemo.hermes', '0.0.1', False)
+    osso_context = osso.Context('org.maemo.hermes', '0.0.2', False)
     self.app.add_window(self.window)
 
     self.window.connect("delete-event", gtk.main_quit)
